<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Tennessee";
    var qsoPartyUrl = "http://tnqp.org/";
    var overlayUrl = "http://www.no5w.com/OverlayTennesseeRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Anderson", "ande");
  countySelection.options[1] = new Option("Bedford", "bedf");
  countySelection.options[2] = new Option("Benton", "bent");
  countySelection.options[3] = new Option("Bledsoe", "bled");
  countySelection.options[4] = new Option("Blount", "blou");
  countySelection.options[5] = new Option("Bradley", "brad");
  countySelection.options[6] = new Option("Campbell", "camp");
  countySelection.options[7] = new Option("Cannon", "cann");
  countySelection.options[8] = new Option("Carroll", "carr");
  countySelection.options[9] = new Option("Carter", "cart");
  countySelection.options[10] = new Option("Cheatham", "chea");
  countySelection.options[11] = new Option("Chester", "ches");
  countySelection.options[12] = new Option("Claiborne", "clai");
  countySelection.options[13] = new Option("Clay", "clay");
  countySelection.options[14] = new Option("Cocke", "cock");
  countySelection.options[15] = new Option("Coffee", "coff");
  countySelection.options[16] = new Option("Crockett", "croc");
  countySelection.options[17] = new Option("Cumberland", "cumb");
  countySelection.options[18] = new Option("Davidson", "davi");
  countySelection.options[19] = new Option("Decatur", "deca");
  countySelection.options[20] = new Option("DeKalb", "deka");
  countySelection.options[21] = new Option("Dickson", "dick");
  countySelection.options[22] = new Option("Dyer", "dyer");
  countySelection.options[23] = new Option("Fayette", "faye");
  countySelection.options[24] = new Option("Fentress", "fent");
  countySelection.options[25] = new Option("Franklin", "fran");
  countySelection.options[26] = new Option("Gibson", "gibs");
  countySelection.options[27] = new Option("Giles", "gile");
  countySelection.options[28] = new Option("Grainger", "grai");
  countySelection.options[29] = new Option("Greene", "gree");
  countySelection.options[30] = new Option("Grundy", "grun");
  countySelection.options[31] = new Option("Hamblen", "hamb");
  countySelection.options[32] = new Option("Hamilton", "hami");
  countySelection.options[33] = new Option("Hancock", "hanc");
  countySelection.options[34] = new Option("Hardeman", "hard");
  countySelection.options[35] = new Option("Hardin", "harn");
  countySelection.options[36] = new Option("Hawkins", "hawk");
  countySelection.options[37] = new Option("Haywood", "hayw");
  countySelection.options[38] = new Option("Henderson", "hend");
  countySelection.options[39] = new Option("Henry", "henr");
  countySelection.options[40] = new Option("Hickman", "hick");
  countySelection.options[41] = new Option("Houston", "hous");
  countySelection.options[42] = new Option("Humphreys", "hump");
  countySelection.options[43] = new Option("Jackson", "jack");
  countySelection.options[44] = new Option("Jefferson", "jeff");
  countySelection.options[45] = new Option("Johnson", "john");
  countySelection.options[46] = new Option("Knox", "knox");
  countySelection.options[47] = new Option("Lake", "lake");
  countySelection.options[48] = new Option("Lauderdale", "laud");
  countySelection.options[49] = new Option("Lawrence", "lawr");
  countySelection.options[50] = new Option("Lewis", "lewi");
  countySelection.options[51] = new Option("Lincoln", "linc");
  countySelection.options[52] = new Option("Loudon", "loud");
  countySelection.options[53] = new Option("Macon", "maco");
  countySelection.options[54] = new Option("Madison", "madi");
  countySelection.options[55] = new Option("Marion", "mari");
  countySelection.options[56] = new Option("Marshall", "mars");
  countySelection.options[57] = new Option("Maury", "maur");
  countySelection.options[58] = new Option("McMinn", "mcmi");
  countySelection.options[59] = new Option("McNairy", "mcna");
  countySelection.options[60] = new Option("Meigs", "meig");
  countySelection.options[61] = new Option("Monroe", "monr");
  countySelection.options[62] = new Option("Montgomery", "mont");
  countySelection.options[63] = new Option("Moore", "moor");
  countySelection.options[64] = new Option("Morgan", "morg");
  countySelection.options[65] = new Option("Obion", "obio");
  countySelection.options[66] = new Option("Overton", "over");
  countySelection.options[67] = new Option("Perry", "perr");
  countySelection.options[68] = new Option("Pickett", "pick");
  countySelection.options[69] = new Option("Polk", "polk");
  countySelection.options[70] = new Option("Putnam", "putn");
  countySelection.options[71] = new Option("Rhea", "rhea");
  countySelection.options[72] = new Option("Roane", "roan");
  countySelection.options[73] = new Option("Robertson", "robe");
  countySelection.options[74] = new Option("Rutherford", "ruth");
  countySelection.options[75] = new Option("Scott", "scot");
  countySelection.options[76] = new Option("Sequatchie", "sequ");
  countySelection.options[77] = new Option("Sevier", "sevi");
  countySelection.options[78] = new Option("Shelby", "shel");
  countySelection.options[79] = new Option("Smith", "smit");
  countySelection.options[80] = new Option("Stewart", "stew");
  countySelection.options[81] = new Option("Sullivan", "sull");
  countySelection.options[82] = new Option("Sumner", "sumn");
  countySelection.options[83] = new Option("Tipton", "tipt");
  countySelection.options[84] = new Option("Trousdale", "trou");
  countySelection.options[85] = new Option("Unicoi", "unic");
  countySelection.options[86] = new Option("Union", "unio");
  countySelection.options[87] = new Option("VanBuren", "vanb");
  countySelection.options[88] = new Option("Warren", "warr");
  countySelection.options[89] = new Option("Washington", "wash");
  countySelection.options[90] = new Option("Wayne", "wayn");
  countySelection.options[91] = new Option("Weakley", "weak");
  countySelection.options[92] = new Option("White", "whit");
  countySelection.options[93] = new Option("Williamson", "will");
  countySelection.options[94] = new Option("Wilson", "wils");
  addMarker(36.10600000, -84.19580000, "Anderson", "ande");
  addMarker(35.51140000, -86.45000000, "Bedford", "bedf");
  addMarker(36.08590000, -88.07050000, "Benton", "bent");
  addMarker(35.56290000, -85.17570000, "Bledsoe", "bled");
  addMarker(35.67390000, -83.92560000, "Blount", "blou");
  addMarker(35.17270000, -84.86180000, "Bradley", "brad");
  addMarker(36.38490000, -84.13820000, "Campbell", "camp");
  addMarker(35.80870000, -86.04700000, "Cannon", "cann");
  addMarker(35.96990000, -88.44230000, "Carroll", "carr");
  addMarker(36.30750000, -82.13710000, "Carter", "cart");
  addMarker(36.24890000, -87.09710000, "Cheatham", "chea");
  addMarker(35.42000000, -88.59690000, "Chester", "ches");
  addMarker(36.46640000, -83.67860000, "Claiborne", "clai");
  addMarker(36.51490000, -85.54050000, "Clay", "clay");
  addMarker(35.94760000, -83.10770000, "Cocke", "cock");
  addMarker(35.49700000, -86.07480000, "Coffee", "coff");
  addMarker(35.83590000, -89.12710000, "Crockett", "croc");
  addMarker(35.95850000, -84.97670000, "Cumberland", "cumb");
  addMarker(36.18660000, -86.78520000, "Davidson", "davi");
  addMarker(35.61490000, -88.10940000, "Decatur", "deca");
  addMarker(35.97860000, -85.84700000, "DeKalb", "deka");
  addMarker(36.14690000, -87.35300000, "Dickson", "dick");
  addMarker(36.04690000, -89.44380000, "Dyer", "dyer");
  addMarker(35.19920000, -89.41410000, "Fayette", "faye");
  addMarker(36.35710000, -84.89070000, "Fentress", "fent");
  addMarker(35.17560000, -86.09830000, "Franklin", "fran");
  addMarker(36.00700000, -88.94940000, "Gibson", "gibs");
  addMarker(35.22390000, -87.03040000, "Giles", "gile");
  addMarker(36.25060000, -83.49400000, "Grainger", "grai");
  addMarker(36.17030000, -82.87490000, "Greene", "gree");
  addMarker(35.37360000, -85.69960000, "Grundy", "grun");
  addMarker(36.21330000, -83.27550000, "Hamblen", "hamb");
  addMarker(35.22110000, -85.20890000, "Hamilton", "hami");
  addMarker(36.49320000, -83.15130000, "Hancock", "hanc");
  addMarker(35.21340000, -88.99000000, "Hardeman", "hard");
  addMarker(35.20940000, -88.18100000, "Hardin", "harn");
  addMarker(36.41810000, -82.94440000, "Hawkins", "hawk");
  addMarker(35.60990000, -89.28610000, "Haywood", "hayw");
  addMarker(35.62060000, -88.39640000, "Henderson", "hend");
  addMarker(36.31100000, -88.26040000, "Henry", "henr");
  addMarker(35.80120000, -87.47260000, "Hickman", "hick");
  addMarker(36.27310000, -87.74740000, "Houston", "hous");
  addMarker(36.02430000, -87.77620000, "Humphreys", "hump");
  addMarker(36.36760000, -85.66840000, "Jackson", "jack");
  addMarker(36.04380000, -83.47240000, "Jefferson", "jeff");
  addMarker(36.43800000, -81.85290000, "Johnson", "john");
  addMarker(35.99010000, -83.96220000, "Knox", "knox");
  addMarker(36.34430000, -89.52290000, "Lake", "lake");
  addMarker(35.74300000, -89.64900000, "Lauderdale", "laud");
  addMarker(35.22860000, -87.40460000, "Lawrence", "lawr");
  addMarker(35.52900000, -87.49350000, "Lewis", "lewi");
  addMarker(35.18080000, -86.57710000, "Lincoln", "linc");
  addMarker(35.75540000, -84.35880000, "Loudon", "loud");
  addMarker(36.52580000, -86.00850000, "Macon", "maco");
  addMarker(35.61240000, -88.84120000, "Madison", "madi");
  addMarker(35.15120000, -85.61750000, "Marion", "mari");
  addMarker(35.48190000, -86.78010000, "Marshall", "mars");
  addMarker(35.62940000, -87.06820000, "Maury", "maur");
  addMarker(35.44280000, -84.63040000, "McMinn", "mcmi");
  addMarker(35.19030000, -88.57470000, "McNairy", "mcna");
  addMarker(35.52020000, -84.82510000, "Meigs", "meig");
  addMarker(35.43900000, -84.23220000, "Monroe", "monr");
  addMarker(36.47810000, -87.37720000, "Montgomery", "mont");
  addMarker(35.26750000, -86.39200000, "Moore", "moor");
  addMarker(36.14250000, -84.62800000, "Morgan", "morg");
  addMarker(36.35440000, -89.14990000, "Obion", "obio");
  addMarker(36.34250000, -85.29000000, "Overton", "over");
  addMarker(35.63220000, -87.84590000, "Perry", "perr");
  addMarker(36.51610000, -85.00840000, "Pickett", "pick");
  addMarker(35.13660000, -84.53410000, "Polk", "polk");
  addMarker(36.14140000, -85.45480000, "Putnam", "putn");
  addMarker(35.61720000, -84.92890000, "Rhea", "rhea");
  addMarker(35.84670000, -84.52630000, "Roane", "roan");
  addMarker(36.50100000, -86.85730000, "Robertson", "robe");
  addMarker(35.85960000, -86.42100000, "Rutherford", "ruth");
  addMarker(36.38340000, -84.51730000, "Scott", "scot");
  addMarker(35.35740000, -85.41660000, "Sequatchie", "sequ");
  addMarker(35.80290000, -83.52430000, "Sevier", "sevi");
  addMarker(35.20180000, -89.97150000, "Shelby", "shel");
  addMarker(36.25400000, -85.95770000, "Smith", "smit");
  addMarker(36.50350000, -87.83140000, "Stewart", "stew");
  addMarker(36.50420000, -82.26450000, "Sullivan", "sull");
  addMarker(36.44830000, -86.47980000, "Sumner", "sumn");
  addMarker(35.51110000, -89.82460000, "Tipton", "tipt");
  addMarker(36.39110000, -86.12820000, "Trousdale", "trou");
  addMarker(36.10740000, -82.41860000, "Unicoi", "unic");
  addMarker(36.29840000, -83.83860000, "Union", "unio");
  addMarker(35.67780000, -85.43440000, "VanBuren", "vanb");
  addMarker(35.67830000, -85.77760000, "Warren", "warr");
  addMarker(36.27170000, -82.50120000, "Washington", "wash");
  addMarker(35.24770000, -87.79870000, "Wayne", "wayn");
  addMarker(36.28270000, -88.73810000, "Weakley", "weak");
  addMarker(35.92440000, -85.44800000, "White", "whit");
  addMarker(35.87580000, -86.90760000, "Williamson", "will");
  addMarker(36.15620000, -86.30460000, "Wilson", "wils");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

